<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00049000AgrupamentoContratosFaturamentoFactory {
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getParametrosFatContratos($nrseqcontratos, $params){
        $sql = "SELECT DISTINCT ITNEGO.NRPARCFATURA
                FROM FCT_ITNEGOCIACAOCONTRATO ITNEGO
                JOIN FCT_NEGOCIACAOCONTRATO NEGOCIACAO
                  ON ITNEGO.NRNEGOCIACAOCONTRATO = NEGOCIACAO.NRNEGOCIACAOCONTRATO
                  AND ITNEGO.NRORG             = NEGOCIACAO.NRORG
                JOIN FCT_CONTRATO CONT
                  ON NEGOCIACAO.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                  AND NEGOCIACAO.NRORG        = CONT.NRORG
                WHERE CONT.NRSEQCONTRATO IN($nrseqcontratos)
                    OR CONT.NRSEQCONTRATO IN(SELECT NRSEQCONTRATO 
                                             FROM FCT_RELACAGRUPAMENTOCONT 
                                             WHERE NRAGRUPAMENTO = :NRAGRUPAMENTO
                                                AND NRORG        = :NRORG)
                    AND CONT.NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function insereContrAgrup($params){
        $sql = "INSERT INTO FCT_RELACAGRUPAMENTOCONT(
                            NRAGRUPAMENTOCONT, NRAGRUPAMENTO, NRSEQCONTRATO, IDFATCONTJUNT, NRORG, IDATIVO, 
                            DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                    VALUES (:NRAGRUPAMENTOCONT, :NRAGRUPAMENTO, :NRSEQCONTRATO, NULL, :NRORG, 'S', 
                            SYSDATE, :NRORG, :OPERADOR)";
                            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Retorna os parâmetros de faturamento do escopo
    **/
    public function getParametrosFaturamentoEscopo($escopos, $nrorg) {
        $sql = "SELECT DISTINCT PFESC.CDTIPOOPERFATURA,
                     PFESC.CDSERIENF,
                     PFESC.CDEMPRESA,
                     PFESC.CDINSCESTA,
                     PFESC.CDINSCMUNI,
                     PFESC.CDFILIALFATURA
                FROM FCT_TIPOORCAMENTO ESCOPO 
                LEFT JOIN FCT_CAPAPARAMFATESC PFESC
                  ON ESCOPO.NRTIPOORCAMENTO = PFESC.NRTIPOORCAMENTO
                 AND ESCOPO.NRORG           = PFESC.NRORG
                WHERE ESCOPO.NRTIPOORCAMENTO IN ($escopos)
                 AND ESCOPO.NRORG = $nrorg";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Retorna as competências do escopo
    **/
    public function getCompetenciasFaturamentoEscopo($escopos, $nrorg) {
        $sql = "SELECT DISTINCT NRDIACOMPETINI,
                       NRDIACOMPETFIN,
                       IDMESCOMPETINI,
                       IDMESCOMPETFIN,
                       QTDIASAPURACAO,
                       IDTPCALCVENC,
                       NRDIACALCVENC,
                       IDMESCALCVENC,
                       QTDIASFATUVENC,
                       '_' || LISTAGG(NRTIPOORCAMENTO, '_') WITHIN GROUP(ORDER BY NRTIPOORCAMENTO) || '_' AS NRTIPOORCAMENTO
                FROM FCT_PARAMFATESC
                WHERE NRTIPOORCAMENTO IN($escopos)
                    AND NRORG = $nrorg
                GROUP BY NRDIACOMPETINI,
                       NRDIACOMPETFIN,
                       IDMESCOMPETINI,
                       IDMESCOMPETFIN,
                       QTDIASAPURACAO,
                       IDTPCALCVENC,
                       NRDIACALCVENC,
                       IDMESCALCVENC,
                       QTDIASFATUVENC";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Retorna os parâmetros de faturamento dos serviços dos escopos
    **/
    public function getParametrosFaturamentoServicoDoEscopo($escopos, $nrorg) {
        $sql = "SELECT DISTINCT PFIT.CDTIPOOPERFATURA,
                     PFIT.CDSERIENF,
                     PFIT.CDEMPRESA,
                     PFIT.CDINSCESTA,
                     PFIT.CDINSCMUNI,
                     PFIT.CDFILIALFATURA
                FROM FCT_TIPOORCAMENTO ESCOPO 
                LEFT JOIN FCT_PARAMFATITESC PFIT
                  ON ESCOPO.NRTIPOORCAMENTO = PFIT.NRTIPOORCAMENTO
                 AND ESCOPO.NRORG           = PFIT.NRORG
                WHERE ESCOPO.NRTIPOORCAMENTO IN ($escopos)
                 AND ESCOPO.NRORG = $nrorg";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Retorna as competências dos serviços dos escopos
    **/
    public function getCompetenciasFaturamentoServicoDoEscopo($escopos, $nrorg) {
        $sql = "SELECT DISTINCT PFIT.NRDIACOMPETINI,
                       PFIT.NRDIACOMPETFIN,
                       PFIT.IDMESCOMPETINI,
                       PFIT.IDMESCOMPETFIN,
                       PFIT.QTDIASAPURACAO,
                       PFIT.IDTPCALCVENC,
                       PFIT.NRDIACALCVENC,
                       PFIT.IDMESCALCVENC,
                       PFIT.QTDIASFATUVENC,
                       '_' || LISTAGG(NRTIPOORCAMENTO, '_') WITHIN GROUP(ORDER BY NRTIPOORCAMENTO) || '_' AS NRTIPOORCAMENTO
                FROM FCT_PARAMFATITESCSERV PFIT
                INNER JOIN FCT_ITESCOPOPROPOSTA IT
                    ON PFIT.NRITESCOPOPROPOSTA = IT.NRITESCOPOPROPOSTA
                    AND PFIT.NRORG             = IT.NRORG
                WHERE IT.NRTIPOORCAMENTO IN($escopos)
                    AND IT.NRORG = $nrorg
                GROUP BY NRDIACOMPETINI,
                   NRDIACOMPETFIN,
                   IDMESCOMPETINI,
                   IDMESCOMPETFIN,
                   QTDIASAPURACAO,
                   IDTPCALCVENC,
                   NRDIACALCVENC,
                   IDMESCALCVENC,
                   QTDIASFATUVENC";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Salva os escopos ligados ao agrupamento
    **/
    public function salvarEscoposAgrupamento(array $params) {
        $sql = "INSERT INTO FCT_RELACESCOPOAGRUPAMENTO (
                    NRRELACESCAGRUP, NRTIPOORCAMENTO, NRAGRUPAMENTO, 
                    NRORG,           NRORGINCLUSAO,   CDOPERINCLUSAO, 
                    IDATIVO,         DTINCLUSAO
                ) VALUES (
                    :NRRELACESCAGRUP, :NRTIPOORCAMENTO, :NRAGRUPAMENTO, 
                    :NRORG,           :NRORGINCLUSAO,   :CDOPERINCLUSAO, 
                    :IDATIVO,         SYSDATE
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}